export interface IlogScribe {
    l: (...payload: any) => void;
    log: (...payload: any) => void;
    logprint: (...payload: any) => void;
    lp: (...payload: any) => void;
    p: (...payload: any) => void;
    print: (...payload: any) => void;
}
export interface Isettings {
    logDirPath: string;
    logMaxSize: number;
    logPrefix: string;
    printDisabled: boolean;
    printTagColor: string;
}
/**
 * Returns a tag that is suitable for printting.
 * @param {string} tag - A tag to be printed.
 * @param {color} color - Color of the tag text.
 * @returns {string} - A formatted tag.
 */
export declare const getTagForPrint: (tag: string, color?: string | undefined) => string;
/**
 * Returns a tag that is suitable for logging.
 * @param {string} tag - A tag to be logged.
 * @returns {string} - A formatted tag.
 */
export declare const getTagForLog: (tag?: string | undefined) => string;
/**
 * Logs text to a log file.
 * @param payload - A message to log.
 * @returns {Promise<string>} - A message that was saved.
 */
export declare const log: (...payload: any) => void;
export declare const l: (...payload: any) => void;
/**
 * Prints text to console.
 * @param payload - A message to print.
 */
export declare const print: (...payload: any) => void;
export declare const p: (...payload: any) => void;
/**
 * Logs and prints a message.
 * A combination of log() and print().
 * @param payload - A message to print and log.
 */
export declare const logprint: (...payload: any) => void;
export declare const lp: (...payload: any) => void;
/**
 * Sets default directory path for the log files.
 * @param {string} value - A new value to be saved.
 */
export declare const setLogDirPath: (value: string) => void;
/**
 * Sets maximum size for the log files (1000 = 1KB).
 * @param {string} value - A new value to be saved.
 */
export declare const setLogMaxSize: (value: number) => void;
/**
 * Sets prefix for the log files (e.g. application_).
 * @param {string} value - A new value to be saved.
 */
export declare const setLogPrefix: (value: string) => void;
/**
 * Disables printing.
 * @param {string} value - A new value to be saved.
 */
export declare const setPrintDisabled: (value: boolean) => void;
/**
 * Returns everything this module has to provide but with a
 * global tag attached.
 * @param tag - A tag to be logged.
 * @param color A tag color to be used, e.g. "\x1b[36m".
 */
export declare const logscribe: (tag: string, color?: string | undefined) => IlogScribe;
export default logscribe;
